(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     32253,        918]*)
(*NotebookOutlinePosition[     50987,       1625]*)
(*  CellTagsIndexPosition[     50943,       1621]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Cap\[IAcute]tulo 3
Elementos de Integraci\[OAcute]n Num\[EAcute]rica\
\>", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell["\<\
En este cap\[IAcute]tulo se expone el procedimiento general para \
encontrar el \[AAcute]rea bajo un segmento de una funci\[OAcute]n arbitraria \
a trav\[EAcute]s de aproximaciones. Tambi\[EAcute]n se utilizan a las reglas \
del trapecio y de Simpson en ejemplos para calcular el \[AAcute]rea bajo la \
gr\[AAcute]fica de funciones. Finalmente, se  introduce una interpretaci\
\[OAcute]n al \[AAcute]rea bajo la curva de una se\[NTilde]al \
(funci\[OAcute]n), conocida como electromiograf\[IAcute]a, que es originada \
por fen\[OAcute]menos bioel\[EAcute]ctricos. \
\>", "MathCaption",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["Introducci\[OAcute]n", "Section",
  Evaluatable->False],

Cell["Las \[AAcute]reas como l\[IAcute]mites de sumas", "Subsection",
  Evaluatable->False],

Cell["\<\
El c\[AAcute]lculo del \[AAcute]rea bajo una curva arbitraria dada \
consiste en dividir a la regi\[OAcute]n de inter\[EAcute]s en secciones \
regulares, la suma de las \[AAcute]reas de estas regiones se aproximar\
\[AAcute] al \[AAcute]rea de la regi\[OAcute]n deseada. De esta manera, al \
escoger un n\[UAcute]mero grande de regiones, cada vez m\[AAcute]s peque\
\[NTilde]as, nos acercaremos al \[AAcute]rea de inter\[EAcute]s con mayor \
precisi\[OAcute]n. 
Para describir en general este procedimiento de c\[AAcute]lculo es entonces \
necesario recurrir a los conceptos de funci\[OAcute]n y l\[IAcute]mite.\
\>", \
"Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Supongamos que y = f (x) es una funci\[OAcute]n cuya \
gr\[AAcute]fica es una curva arbitraria que conecta dos puntos A y B en el \
plano cartesiano seg\[UAcute]n se muestra en la siguiente figura :
\
\>", "Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "f[x_]:=3 x (1-x^6)+5\na=0.1;\nb=1;\n\ng1=Plot[f[x], {x,-0.1,1}, PlotRange \
\[Rule] {-1,7}, \n AxesLabel \[Rule] {\"X\",\"Y\"}, DisplayFunction \[Rule] \
Identity ];\n\ng2=Text[\"A\", {a,f[a]+1}];\n\ng2b=Text[\"B\", {b,f[b]+1}];\n\n\
g2c=Text[\"a\", {a,-1}];\n\ng2d=Text[\"b\", {b,-1}];\n\ng2e=ListPlot[{{a, 0}, \
{a, f[a]}}, PlotJoined \[Rule] True,\n DisplayFunction \[Rule] Identity];\n\n\
g2f=ListPlot[{{b, 0}, {b, f[b]}}, PlotJoined \[Rule] True,\n DisplayFunction \
\[Rule] Identity];\n\nShow[g1, Graphics[g2], Graphics[g2b], Graphics[g2c],\n \
Graphics[g2d], ",
  Cell[BoxData[
      \(TraditionalForm\`g2e\)]],
  ", g2f,\n DisplayFunction \[Rule] $DisplayFunction ];"
}], "Input",
  CellLabel->"In[261]:=",
  PageWidth->Infinity],

Cell["\<\
Queremos encontrar el \[AAcute]rea de la secci\[OAcute]n bajo el \
segmento A-B de la curva a trav\[EAcute]s de un m\[EAcute]todo de aproximaci\
\[OAcute]n. La secci\[OAcute]n est\[AAcute] limitada superiormente por la gr\
\[AAcute]fica de la funci\[OAcute]n y = f (x), inferiormente por la porci\
\[OAcute]n del eje X desde X=a hasta X=b, y finalmente en la izquierda y la \
derecha por dos l\[IAcute]neas rectas paralelas al eje Y.\
\>", "Text",
  Evaluatable->False,
  TextJustification->1],

Cell[BoxData[{
    \(<< Graphics`FilledPlot`\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(g3 = 
        FilledPlot[f[x], {x, a, b}, \ 
          PlotRange\  \[Rule] \ {0, 
              7}, \[IndentingNewLine]DisplayFunction \[Rule] \ 
            Identity];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Show[g1, g3, Graphics[g2], 
        Graphics[g2b], \ \[IndentingNewLine]Graphics[g2c], \ 
        Graphics[
          g2d], \ \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction\
\ ];\)\)}], "Input",
  CellLabel->"In[279]:=",
  PageWidth->Infinity,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Dividamos al eje X bajo la curva en N partes iguales (o subintervalos).  \
La abscisa X del punto inicial A es ",
  Cell[BoxData[
      \(TraditionalForm\`X\_o\)]],
  ", la abscisa del siguiente punto es ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  ", la del tercer punto ",
  Cell[BoxData[
      \(TraditionalForm\`X\_2\)]],
  ", y as\[IAcute] sucesivamente de tal manera que la abscisa X del  \
\[UAcute]ltimo punto ser\[AAcute] ",
  Cell[BoxData[
      \(TraditionalForm\`X\_N\)]],
  ". Sea ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_0\)]],
  " un punto escogido en el primer subintervalo [",
  Cell[BoxData[
      \(TraditionalForm\`X\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  "] tal que ",
  Cell[BoxData[
      \(TraditionalForm\`X\_o\)]],
  " \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_0\)]],
  " \[LessEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  ", sea  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_1\)]],
  "  un punto escogido en el segundo subintervalo y as\[IAcute] sucesivamente \
 hasta completar los N subintervalos (",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_i\)]],
  " ser\[AAcute] el punto seleccionado en el i \"esimo\" subintervalo [",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(i - 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i\)]],
  "]). Sea ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_xi\)]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(X\_i\), "-", " ", 
            FormBox[\(X\_\(i - 1\)\),
              "TraditionalForm"]}], "  "}], TraditionalForm]]],
  "el tama\[NTilde]o del i \"esimo\" subintervalo. En los extremos de cada  \
subintervalo [",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(i - 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i\)]],
  "] se construyen dos l\[IAcute]neas perpendiculares al eje Y cuya altura \
(",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_yi\)]],
  ") ser\[AAcute] el valor de la funci\[OAcute]n evaluada en ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_i\)]],
  ", f(",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_i\)]],
  "). En cada subintervalo se define entonces a un rect\[AAcute]ngulo cuya  \
\[AAcute]rea ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_xi\)]],
  ". f( ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_i\)]],
  ") es una aproximaci\[OAcute]n al \[AAcute]rea bajo la curva sobre ese  \
subintervalo."
}], "Text",
  Evaluatable->False,
  TextJustification->1],

Cell["\<\
g4=Rectangle[{0.2,0}, {0.3, f[0.25]}];

Show[g1, g3, Graphics[g4], Graphics[g2],
 Graphics[g2b], Graphics[g2c], Graphics[g2d], 
 DisplayFunction\[Rule]$DisplayFunction ];\
\>", "Input",
  CellLabel->"In[286]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "Repitiendo este proceso para cada subintervalo y calculando la suma de las \
\[AAcute]reas de cada rect\[AAcute]ngulo se obtiene una aproximaci\[OAcute]n \
de toda el \[AAcute]rea bajo la curva. Es decir al formar las siguientes \
sumas:\n\t",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Xi]\_1\)\()\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_x1\)]],
  " + ",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Xi]\_2\)\()\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(\(x2\)\(\ \)\)\)]],
  "+ ...",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Xi]\_i\)\()\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_xi\)]],
  " + ...",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Xi]\_N\)\()\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_xN\)]],
  " \no bien\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
          RowBox[{
            StyleBox["f",
              "Text"], 
            StyleBox["(",
              "Text"], 
            RowBox[{
              FormBox[\(\(\[Xi]\_i\)\()\)\),
                "TraditionalForm"], " ", 
              FormBox[\(\[CapitalDelta]\_xi\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "\nse obtiene la expresi\[OAcute]n conocida como ",
  StyleBox["suma de Riemann",
    FontSlant->"Italic"],
  " que es una aproximaci\[OAcute]n al \[AAcute]rea bajo la curva y = f(x)  \
sobre el intervalo [a,b].  Al aumentar el n\[UAcute]mero de subintervalos  \
regulares y por lo tanto reducir el tama\[NTilde]o (",
  Cell[BoxData[
      RowBox[{
        FormBox["",
          "TraditionalForm"], 
        FormBox[\(\[CapitalDelta]\_xi\),
          "TraditionalForm"]}]]],
  ")  de los mismos podemos mejorar la aproximaci\[OAcute]n; en el  \
l\[IAcute]mite, cuando el n\[UAcute]mero de subintervalos tiende a infinito,  \
la suma de los muy angostos elementos de \[AAcute]rea se conoce como la  \
integral definida de la funci\[OAcute]n y = f(x) entre los valores x = a y x  \
= b. Es decir usando la notaci\[OAcute]n de Leibniz:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( f(x)\) dx\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`lim\+\(N \[Rule] \[Infinity]\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%N\(\( 
            f(\[Zeta]i)\) \(\[CapitalDelta]x\)\(\ \ \)\)\)]],
  "...(1)\nen donde \[Integral] es el s\[IAcute]mbolo para representar al  \
\[AAcute]rea en el l\[IAcute]mite.\nA trav\[EAcute]s de la integral definida \
es entonces posible calcular el \[AAcute]rea de la regi\[OAcute]n bajo la \
curva en el intervalo [a,b]. \nUtilicemos ahora al paquete computacional para \
ilustrar estos conceptos."
}], "Text",
  Evaluatable->False,
  TextJustification->1],

Cell[" Ejemplos con Mathematica", "Section",
  Evaluatable->False],

Cell["Definamos a una funci\[OAcute]n, por ejemplo,", "Text",
  Evaluatable->False],

Cell["f[x_]:=x^3", "Input",
  CellLabel->"In[387]:=",
  PageWidth->Infinity],

Cell["Grafiquemos a la funci\[OAcute]n en el intervalo [0, 2.5]", "Text",
  Evaluatable->False],

Cell["\<\
Plot[f[x], {x,0,2.5}, AxesLabel \[Rule] {\"x\" ,\"f(x)\"},
 PlotLabel \[Rule] \"f(x)=x^3\" ];\
\>", "Input",
  CellLabel->"In[388]:=",
  PageWidth->Infinity],

Cell["\<\
Definamos tambi\[EAcute]n a un intervalo [a, b], en el eje x, en \
donde se quiere calcular el \[AAcute]rea bajo la curva, por ejemplo:\
\>", \
"Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
a=1;
b=2;

<<Graphics`FilledPlot`

Show[
 FilledPlot[f[x], {x,a,b}, DisplayFunction \[Rule] Identity],
 Plot[f[x], {x,0,2.5}, DisplayFunction \[Rule] Identity],
 AxesLabel \[Rule] {\"x\",\"y\"}, PlotLabel \[Rule] \"y=x^3\",
 DisplayFunction\[Rule]$DisplayFunction ];\
\>", "Input",
  CellLabel->"In[393]:=",
  PageWidth->Infinity],

Cell["\<\
Definamos ahora al n\[UAcute]mero de intervalos regulares en la \
partici\[OAcute]n, o n\[UAcute]mero de secciones rectangulares, que \
utilizaremos para aproximar el \[AAcute]rea de la regi\[OAcute]n de inter\
\[EAcute]s:\
\>", "Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["n=4;", "Input",
  CellLabel->"In[432]:=",
  PageWidth->Infinity],

Cell["\<\
La siguiente expresi\[OAcute]n nos permite encontar el \
tama\[NTilde]o de los intervalos o el tama\[NTilde]o de la base de los rect\
\[AAcute]ngulos individuales: \
\>", "Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["dx=(b-a)/n", "Input",
  CellLabel->"In[433]:=",
  PageWidth->Infinity],

Cell["\<\
Calculemos la suma de Riemann en el intervalo [a, b] \
correspondiente a esta partici\[OAcute]n. Para esto seg\[UAcute]n la ecuaci\
\[OAcute]n (1) es necesario evaluar a la funci\[OAcute]n f(x) en un punto \
intermedio de cada uno de los subintervalos definidos por la \
partici\[OAcute]n, escojamos xo como este punto para el primer subintervalo \
tal cual se define a continuaci\[OAcute]n: \
\>", "Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["xo=a+0.5 dx;", "Input",
  CellLabel->"In[434]:=",
  PageWidth->Infinity],

Cell["\<\
Podemos completar el c\[AAcute]lculo de la suma de Riemann tomando \
como puntos base para evaluar a la funci\[OAcute]n en los restantes \
subintervalos: \
\>", "Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["NSum[f[xo+(i-1)*dx]*dx, {i,1,n}]", "Input",
  CellLabel->"In[435]:=",
  PageWidth->Infinity],

Cell["\<\
El valor anterior representa nuestra aproximaci\[OAcute]n al area \
de inter\[EAcute]s. Con objeto de comparar el resultado, c\[AAcute]lculemos a \
continuaci\[OAcute]n el valor exacto del \[AAcute]rea de la regi\[OAcute]n de \
inter\[EAcute]s evaluando en los l\[IAcute]mites [1,3] al resultado de la \
integral definida\
\>", "Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["area=NIntegrate[f[x], {x,a,b}]", "Input",
  CellLabel->"In[436]:=",
  PageWidth->Infinity],

Cell["\<\
 Ejercicios:

1.- \[DownQuestion]Qu\[EAcute] tan precisa fue la aproximaci\[OAcute]n?

2.- Repetir y evaluar la aproximaci\[OAcute]n para n=10.
\
\>", "Subsubsection",
  Evaluatable->False],

Cell["\<\
Repitamos ahora el proceso anterior para un n\[UAcute]mero mayor de \
subintervalos y expresemos los resultados en forma de una tabla.  \
\>", \
"Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Clear[n,dx,xo,f];
a=1;
b=2;
f[x_]:=x^3\
\>", "Input",
  CellLabel->"In[420]:=",
  PageWidth->Infinity],

Cell[BoxData[{
    \(dx[n_] := \((b - a)\)/n\), "\[IndentingNewLine]", 
    \(xo[n_] := a + 0.5\ dx[n]\), "\[IndentingNewLine]", 
    \(s[n_] := Sum[f[xo[n] + \((i - 1)\)*dx[n]]*dx[n], {i, 1, n}]\)}], "Input",\

  CellLabel->"In[428]:="],

Cell["\<\
TableForm[
 Table[{2^(n-1),s[2^(n-1)]}, {n,1,11}],
 TableHeadings \[Rule] {None, {\"No. Subintervalos\\n\",
  \"\[CapitalAAcute]rea\\n\"}} ]\
\>", "Input",
  CellLabel->"In[431]:=",
  PageWidth->Infinity],

Cell["\<\

Ejercicios

3 .- Graficar los resultados de la tabla anterior.

4.- \[DownQuestion]Qu\[EAcute] sucede al aumentar el n\[UAcute]mero de \
intervalos regulares en la partici\[OAcute]n ? y  \[DownQuestion]por qu\
\[EAcute]?, \[DownQuestion]a que valor se aproxima el \[AAcute]rea?.

5.- Calcular el error en la aproximaci\[OAcute]n en funci\[OAcute]n del n\
\[UAcute]mero de intervalos, \[DownQuestion]c\[OAcute]mo se comporta este \
error?.

6.- Repitir la experiencia anterior para otras funciones, nuevamente \
\[DownQuestion]qu\[EAcute] tan r\[AAcute]pido se converge al \[AAcute]rea \
deseada?,  \[DownQuestion]c\[OAcute]mo se comportan los errores? .
\
\>", "Subsubsection",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["Otras Aproximaciones", "Section",
  Evaluatable->False],

Cell["Regla del Trapecio", "Subsection",
  Evaluatable->False],

Cell[TextData[{
  "Existen otros m\[EAcute]todos num\[EAcute]ricos para calcular el \
\[AAcute]rea bajo el segmento de una curva arbitraria. Por ejemplo, la regla \
del trapecio aproxima el valor de la integral definida con base en una  \
particion regular del intervalo [a, b] en N subintervalos ( [",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(i - 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i\)]],
  "]) seg\[UAcute]n se establece en la siguiente expresi\[OAcute]n:\n",
  Cell[BoxData[
      \(TextForm\`\[Integral]\_a\%b f \((x)\) dx\)]],
  " ",
  StyleBox["\[TildeFullEqual]",
    FormatType->TextForm,
    FontFamily->"Symbol"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \[CapitalDelta]x\)]],
  " [",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_0\)\()\)\)\)]],
  " + 2",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_1\)\()\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  "+ ... + 2",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_\(N - 1\)\)\()\)\)\)]],
  " + ...",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_N\)\()\)\)\)]],
  " ]   ...(2)\nEn la expresi\[OAcute]n anterior \[CapitalDelta]x corresponde \
al tama\[NTilde]o de los subintervalos regulares e identificamos a dos clases \
de t\[EAcute]rminos; el primero y  el \[UAcute]ltimo se pueden considerar \
como  \[AAcute]reas de tri\[AAcute]ngulos de base \[CapitalDelta]x con altura \
 f(",
  Cell[BoxData[
      \(TraditionalForm\`X\_0\)]],
  ")  y  f(",
  Cell[BoxData[
      \(TraditionalForm\`X\_N\)]],
  ") respectivamente; el resto se pueden considerar como \[AAcute]reas de \
rect\[AAcute]ngulos. Nuevamente podemos utilizar al paquete Mathematica para \
encontrar una aproximaci\[OAcute]n al \[AAcute]rea bajo la curva f(x)=x^3 en  \
el intervalo [1,3] a trav\[EAcute]s de la regla del Trapecio:"
}], "Text",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Clear[n,dx,f];
a=1;
b=2;
n=4;
dx=(b-a)/n;
f[x_]:=x^3\
\>", "Input",
  CellLabel->"In[445]:=",
  PageWidth->Infinity],

Cell["\<\
Para calcular la aproximaci\[OAcute]n trapezoidal separaremos a las \
sumas de la ecuaci\[OAcute]n (2) seg\[UAcute]n las dos clases de secciones \
mencionadas:
\taa  ser\[AAcute] las suma de las \[AAcute]rea de las secciones \
rectangulares\
\>", "Text",
  Evaluatable->False],

Cell["aa=NSum[f[a+(i-1)*dx]*dx, {i,2,n}];", "Input",
  CellLabel->"In[451]:=",
  PageWidth->Infinity],

Cell["\tbb, ser\[AAcute] las suma de las \[AAcute]rea de las secciones \
triangulares", "Text",
  Evaluatable->False],

Cell["bb=(f[a]+f[b])*dx/2;", "Input",
  CellLabel->"In[452]:=",
  PageWidth->Infinity],

Cell["\<\
Por lo tanto el \[AAcute]rea obtenida por la Regla del Trapecio \
para 5 intervalos regulares es\
\>", "Text",
  Evaluatable->False],

Cell["areat=aa+bb", "Input",
  CellLabel->"In[453]:=",
  PageWidth->Infinity],

Cell["\<\

Ejercicios:

7.-Repitir el proceso anterior para un n\[UAcute]mero mayor de intervalos en \
la partici\[OAcute]n y expresar los resultados en forma de una tabla.

8.-Graficar los resultados de la tabla anterior.

9.-Calcular el error en la aproximaci\[OAcute]n en funci\[OAcute]n del n\
\[UAcute]mero de intervalos, \[DownQuestion]c\[OAcute]mo se comporta este \
error?, \[DownQuestion]a qu\[EAcute] valor se aproxima?.

10.-Comparar el error con el obtenido por las sumas de Riemann.

11.-Comparar la convergencia de este m\[EAcute]todo con las sumas de Riemann.
\
\>", "Subsubsection",
  TextAlignment->Left,
  TextJustification->1],

Cell["Regla de Simpson", "Subsubsection"],

Cell[TextData[{
  "La siguiente expresi\[OAcute]n se conoce como Regla de Simpson y  \
representa a otro m\[EAcute]todo num\[EAcute]rico para aproximarse al valor  \
de la integral definida, en este caso el n\[UAcute]mero de subintervalos de  \
la partici\[OAcute]n debe ser par, digamos ",
  StyleBox["n=2m",
    FontWeight->"Bold"],
  ". Una deducci\[OAcute]n de esta f\[OAcute]rmula se puede encontrar en la  \
referencia [3].\n\t",
  Cell[BoxData[
      \(TextForm\`\[Integral]\_a\%b f \((x)\) dx\)]],
  " ",
  StyleBox["\[TildeFullEqual]",
    FormatType->TextForm,
    FontFamily->"Symbol"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/3\) \[CapitalDelta]x\)]],
  " [",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_0\)\()\)\)\)]],
  " + 4",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_1\)\()\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  "+  2",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_2\)\()\)\)\)]],
  " + 4",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_3\)\()\)\)\)]],
  " +  ... + 2",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_\(N - 2\)\)\()\)\)\)]],
  " + 4",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_\(N - 1\)\)\()\)\)\)]],
  "  \t\t\t+ ",
  StyleBox["f(", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(X\_N\)\()\)\)\)]],
  " ]   ...(3)"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\

Ejercicios:

Nuevamente para la funci\[OAcute]n f(x)=x^3 en el intervalo [1, 2], utilice \
la regla de Simpson para:

12.-Calcular el \[AAcute]rea para diferentes particiones y expresar los \
resultados en forma de una tabla.

13.-Graficar los resultados de la tabla anterior.

14.-Calcular el error en la aproximaci\[OAcute]n en funci\[OAcute]n del n\
\[UAcute]mero de particiones, \[DownQuestion]c\[OAcute]mo se comporta este \
error?, \[DownQuestion]a qu\[EAcute] valor se aproxima?.

15.-Comparar el error con el obtenido por la regla del trapecio.

16.-Comparar la convergencia entre este m\[EAcute]todo y la regla del \
trapecio.
\
\>", "Subsubsection",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Determinaci\[OAcute]n de la Actividad Muscular a partir de Datos de \
Electromiograf\[IAcute]a\
\>", "Section"],

Cell[TextData[{
  "El c\[AAcute]lculo del \[AAcute]rea bajo una curva es de utilidad para el \
an\[AAcute]lisis de las siguientes se\[NTilde]ales (o funciones) electromiogr\
\[AAcute]ficas que son el resultado de los fen\[OAcute]menos \
bioel\[EAcute]ctricos generados en las c\[EAcute]lulas musculares.\nLa  \
bioelectricidad se origina en las diferencias de potencial presentes entre el \
exterior e interior de las c\[EAcute]lulas. Estos potenciales surgen como \
resultado de las propiedades de las membranas celulares. Al estimular las c\
\[EAcute]lulas se pueden producir cambios r\[AAcute]pidos -no lineales-, \
conocidos como potenciales de acci\[OAcute]n, en estas diferencias de  \
potencial. Los potenciales de acci\[OAcute]n, caracter\[IAcute]sticos de los \
tejidos excitables, se originan por cambios activos en la permeabilidad de \
las membranas a iones como el sodio y el potasio. ",
  StyleBox["En las c\[EAcute]lulas musculares los potenciales de \
acci\[OAcute]n inicializan la contracci\[OAcute]n muscular.",
    FontWeight->"Bold"],
  "  ",
  StyleBox["La electromiograf\[IAcute]a (EMG) es el registro e interpretaci\
\[OAcute]n  de la suma espacial de los potenciales de acci\[OAcute]n de las  \
c\[EAcute]lulas o fibras musculares",
    FontWeight->"Bold"],
  ". \nPara poder realizar un registro electromiogr\[AAcute]fico es necesario \
 entonces interactuar con estos potenciales;  la interacci\[OAcute]n \
involucra una conversi\[OAcute]n de las corrientes i\[OAcute]nicas asociadas \
al fen\[OAcute]meno bioel\[EAcute]ctrico en corrientes el\[EAcute]ctricas que \
detectan los equipos electr\[OAcute]nicos de medici\[OAcute]n. La conversi\
\[OAcute]n anterior se consigue al utilizar un transductor, conocido como \
electrodo, constituido por conductores el\[EAcute]ctricos en contacto con las \
 soluciones acuosas i\[OAcute]nicas del organismo. En esta superficie de  \
contacto entre el organismo y el electrodo se generan reacciones de  \
\[OAcute]xido reducci\[OAcute]n que transfieren la carga de la  soluci\
\[OAcute]n al electrodo en forma de una peque\[NTilde]a corriente el \
\[EAcute]ctrica. Esta corriente (variable f\[IAcute]sica) es amplificada por \
los equipos electr\[OAcute]nicos y al registrarla o graficarla en funci \
\[OAcute]n del tiempo se obtieneuna se\[NTilde]al electromiogr\[AAcute]fica.  \
\nLas se\[NTilde]ales electromiogr\[AAcute]ficas se modelan como funciones  \
continuas de una variable independiente que es el tiempo y transportan  \
informaci\[OAcute]n \[UAcute]til relacionada con los fen\[OAcute]menos bioel\
\[EAcute]ctricos que ocasionan la contracci\[OAcute]n muscular. Para poder  \
estudiar a estas se\[NTilde]ales con ayuda de las computadoras digitales es  \
aun necesario una etapa de adecuaci\[OAcute]n para la se\[NTilde]al. Lo  \
anterior es necesario debido a que la se\[NTilde]ales son funciones continuas \
 de una variable independiente (el tiempo), esto significa que durante el  \
registro de una se\[NTilde]al electromiogr\[AAcute]fica para cualquier valor  \
del tiempo podr\[IAcute]amos obtener un valor de la variable dependiente; sin \
 embargo,  las computadoras digitales tienen una memoria finita por lo que  \
para almacenar una se\[NTilde]al en la computadora necesitamos discretizar a  \
la variable independiente, es decir, considerar a la variable independiente,  \
el tiempo, como una variable discreta. Lo anterior significa que solo  \
registraremos a la variable dependiente en un conjunto finito de instantes de \
 tiempo separados por un intervalo de tiempo conocido. En otras palabras, \
para  representar a la se\[NTilde]al continua en una computadora usaremos a \
una  serie, que no es mas que un conjunto finito de datos o muestras  de la \
se\[NTilde]al. A pesar de que en este proceso perdemos datos o informaci\
\[OAcute]n, si cumplimos con ciertas condiciones particulares en el muestreo, \
seguiremos representando fielmente a la se\[NTilde]al. \nA  continuaci\
\[OAcute]n, con ayuda del paquete Mathematica, se realiza una  lectura de un \
archivo de texto que contienen datos (o muestras) de una se\[NTilde]al \
electromiogr\[AAcute]fica, obtenida con electrodos superficiales  externos en \
el b\[IAcute]ceps de una persona que cargaba con una mano un  libro de 5.5 \
Kg. ",
  StyleBox["Al emplear este tipo de electrodos se obtiene una se\[NTilde]al \
que  representa una suma espacial de los potenciales de acci\[OAcute]n de \
varias c\[EAcute]lulas o fibras musculares.",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Leamos los datos de la se\[NTilde]al: ", "Text"],

Cell["emg1=ReadList[\"C:\\\\Simulacion\\\\emg1.txt\", Number, 2000];", "Input",
  CellLabel->"In[455]:="],

Cell["Grafiquemos la se\[NTilde]al,", "Text"],

Cell["\<\
ListPlot[emg1, PlotJoined \[Rule] True];\
\>", "Input",
  CellLabel->"In[456]:="],

Cell["\<\
En la gr\[AAcute]fica anterior las unidades en Y corresponden a \
Volts (recordar que la se\[NTilde]al fue previamente amplificada) y las \
unidades en  X corresponden al n\[UAcute]mero de dato o muestra de la se\
\[NTilde]al, notar que se realiz\[OAcute] una lectura de 2000 datos, la \
separaci\[OAcute]n de tiempo entre los datos es conocida y corresponde a \
0.0005 segundos por lo que los 2000 datos representan 1 segundo de actividad \
electromiogr\[AAcute]fica. Escalemos temporalmente entonces a la \
gr\[AAcute]fica anterior.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["t=Table[{i*0.0005,emg1[[i]]}, {i,1,2000}];", "Input",
  CellLabel->"In[457]:="],

Cell["\<\
ListPlot[t, PlotJoined \[Rule] True];\
\>", "Input",
  CellLabel->"In[458]:="],

Cell["\<\
Rectifiquemos la se\[NTilde]al anterior con la funci\[OAcute]n \
valor absoluto:\
\>", "Text"],

Cell["\<\
emg1abs=Abs[emg1];

t=Table[{i*0.0005, emg1abs[[i]]}, {i,1,2000}];\
\>", "Input",
  CellLabel->"In[459]:="],

Cell["Grafiquemos la se\[NTilde]al rectificada:", "Text"],

Cell["\<\
ListPlot[t, PlotJoined \[Rule] True];\
\>", "Input",
  CellLabel->"In[461]:="],

Cell[TextData[{
  StyleBox["El \[AAcute]rea bajo la curva de la figura anterior est\[AAcute]  \
relacionada con el n\[UAcute]mero de fibras musculares que se contrajeron  \
durante la actividad muscular",
    FontWeight->"Bold"],
  ". El \[AAcute]rea constituye entonces una medida indirecta y aproximada al \
 n\[UAcute]mero de fibras musculares necesarias para soportar el libro de 5.5 \
 Kg; este es el tipo de informaci\[OAcute]n que se puede obtener en el  \
contexto del an\[AAcute]lisis de se\[NTilde]ales de electromiograf\[IAcute]a \
con el c\[AAcute]lculo del \[AAcute]rea bajo la curva. Repitamos el proceso  \
anterior para un archivo con datos de electromiograf\[IAcute]a al soportar un \
 libro de 4.0 Kg:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
emg2=ReadList[\"C:\\\\Simulacion\\\\emg2.txt\", Number, 2000];
ListPlot[emg1, PlotJoined \[Rule] True];
emg2abs=Abs[emg2];
ListPlot[emg2abs, PlotJoined \[Rule] True];\
\>", "Input",
  CellLabel->"In[462]:="],

Cell[TextData[{
  "\nEjercicio\n\n17.-\[DownQuestion]C\[OAcute]mo ser\[AAcute] el \
\[AAcute]rea de esta curva, mayor o menor a la del ejemplo anterior? y \
\[DownQuestion]Por qu\[EAcute]?.\n\n18.-Encontrar el \[AAcute]rea bajo la \
curva rectificada con la regla de  Simpson o del trapecio para los 11 \
archivos de electromiograf\[IAcute]a  anexos corespondientes a diferentes \
niveles de actividad muscular en el b \[IAcute]ceps. Los archivos \
corresponden a una persona que carg\[OAcute] en  cada ocasi\[OAcute]n con un \
solo brazo 11 diferentes pesos. Notar que para  este ejercicio el tama\
\[NTilde]o de los subintervalos (\[CapitalDelta]x)  estar\[AAcute] \
determinado por la separaci\[OAcute]n temporal entre las  muestras o datos, \
que para estos archivos fue 0.0005 segundos   (utilizar al  comando ",
  StyleBox["Sum",
    FontFamily->"Times New Roman"],
  " en lugar de NSum, el nombre del archivo sugiere el peso que  gener\
\[OAcute] la actividad).\n\n19.-Graficar el \[AAcute]rea encontrada para  \
cada archivo en funci\[OAcute]n del peso que gener\[OAcute] esa actividad.\n\n\
 20.-\[DownQuestion]Qu\[EAcute] sucede en el m\[UAcute]sculo al aumentar el  \
peso?, \[DownQuestion]qu\[EAcute] se puede concluir?.\n\n21.- Los primeros 8  \
mil datos del archivo ",
  StyleBox["emgtc.txt",
    FontSlant->"Italic"],
  " corresponden a los cuatro segundos iniciales de actividad electromiogr \
\[AAcute]fica en el b\[IAcute]ceps de una persona que soportaba un peso de  \
16.5 Kg y los siguiente 8 mil corresponden a los cuatro segundos siguientes.  \
Calcular el \[AAcute]rea bajo la curva rectificada para los primeros 4  \
segundos de actividad, calcular el \[AAcute]rea bajo la curva rectificada  \
para los siguientes 4 segundos. \[DownQuestion]Qu\[EAcute] le sucedi\[OAcute] \
 al m\[UAcute]sculo?.\n"
}], "Subsubsection"],

Cell["Bibliograf\[IAcute]a", "Section"],

Cell[TextData[{
  "[1] Bronzino. The Biomedical Engineering Handbook. CRC Press, 1995; cap\
\[IAcute]tulos 8, 14, 49, 50, 54\n[2] Kasner, Newman. Mathematics and The \
Imagination. Fireside, 1967\n[3] Swokowski. C\[AAcute]lculo con Geometr\
\[IAcute]a Anal\[IAcute]tica. Grupo Editorial Iberoamercicana, 1989\n[4]  \
Wolfram. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". A system for Doing Mathematics by Computer. 2nd ed, Addison Wesley, \
1991"
}], "Text"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{485, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {72, 72}}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\

Modify the definitions below to change the default appearance of all cells in \

a given style.  Make modifications to any definition using commands in the 
Format menu.
\
\>", "Text",
    TextJustification->1],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\

  The options defined for the style below will be used at the Notebook level. \

 
\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{10, 4}, {2, 50}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\

The cells in this section define styles used for input and output to the 
kernel.  Be careful when modifying, renaming, or removing these styles, 
because the front end associates special meanings with these style names.    

\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->StandardForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 174, 6, 129, "Title",
  Evaluatable->False],
Cell[1894, 57, 917, 22, 127, "MathCaption",
  Evaluatable->False],
Cell[2814, 81, 61, 1, 84, "Section",
  Evaluatable->False],
Cell[2878, 84, 91, 1, 38, "Subsection",
  Evaluatable->False],
Cell[2972, 87, 706, 14, 104, "Text",
  Evaluatable->False],
Cell[3681, 103, 292, 8, 60, "Text",
  Evaluatable->False],
Cell[3976, 113, 756, 14, 418, "Input"],
Cell[4735, 129, 503, 9, 67, "Text",
  Evaluatable->False],
Cell[5241, 140, 627, 15, 146, "Input"],
Cell[5871, 157, 2588, 84, 156, "Text",
  Evaluatable->False],
Cell[8462, 243, 244, 8, 96, "Input"],
Cell[8709, 253, 2932, 78, 324, "Text",
  Evaluatable->False],
Cell[11644, 333, 66, 1, 84, "Section",
  Evaluatable->False],
Cell[11713, 336, 83, 1, 22, "Text",
  Evaluatable->False],
Cell[11799, 339, 76, 2, 28, "Input"],
Cell[11878, 343, 95, 1, 22, "Text",
  Evaluatable->False],
Cell[11976, 346, 167, 5, 45, "Input"],
Cell[12146, 353, 230, 7, 37, "Text",
  Evaluatable->False],
Cell[12379, 362, 340, 13, 181, "Input"],
Cell[12722, 377, 315, 8, 37, "Text",
  Evaluatable->False],
Cell[13040, 387, 70, 2, 28, "Input"],
Cell[13113, 391, 257, 7, 37, "Text",
  Evaluatable->False],
Cell[13373, 400, 76, 2, 28, "Input"],
Cell[13452, 404, 485, 10, 67, "Text",
  Evaluatable->False],
Cell[13940, 416, 78, 2, 28, "Input"],
Cell[14021, 420, 247, 7, 37, "Text",
  Evaluatable->False],
Cell[14271, 429, 98, 2, 28, "Input"],
Cell[14372, 433, 414, 9, 52, "Text",
  Evaluatable->False],
Cell[14789, 444, 96, 2, 28, "Input"],
Cell[14888, 448, 199, 8, 111, "Subsubsection",
  Evaluatable->False],
Cell[15090, 458, 231, 7, 37, "Text",
  Evaluatable->False],
Cell[15324, 467, 112, 7, 79, "Input"],
Cell[15439, 476, 237, 5, 61, "Input"],
Cell[15679, 483, 214, 7, 79, "Input"],
Cell[15896, 492, 757, 21, 248, "Subsubsection",
  Evaluatable->False],
Cell[16656, 515, 61, 1, 84, "Section",
  Evaluatable->False],
Cell[16720, 518, 62, 1, 38, "Subsection",
  Evaluatable->False],
Cell[16785, 521, 2019, 56, 190, "Text",
  Evaluatable->False],
Cell[18807, 579, 126, 9, 113, "Input"],
Cell[18936, 590, 286, 7, 60, "Text",
  Evaluatable->False],
Cell[19225, 599, 101, 2, 28, "Input"],
Cell[19329, 603, 117, 2, 22, "Text",
  Evaluatable->False],
Cell[19449, 607, 86, 2, 28, "Input"],
Cell[19538, 611, 142, 4, 22, "Text",
  Evaluatable->False],
Cell[19683, 617, 77, 2, 28, "Input"],
Cell[19763, 621, 645, 19, 248, "Subsubsection"],
Cell[20411, 642, 41, 0, 35, "Subsubsection"],
Cell[20455, 644, 1534, 52, 108, "Text"],
Cell[21992, 698, 717, 23, 294, "Subsubsection"],
Cell[22712, 723, 121, 3, 106, "Section"],
Cell[22836, 728, 4573, 67, 704, "Text"],
Cell[27412, 797, 54, 0, 22, "Text"],
Cell[27469, 799, 105, 1, 45, "Input"],
Cell[27577, 802, 45, 0, 22, "Text"],
Cell[27625, 804, 91, 3, 28, "Input"],
Cell[27719, 809, 605, 11, 96, "Text"],
Cell[28327, 822, 85, 1, 28, "Input"],
Cell[28415, 825, 88, 3, 28, "Input"],
Cell[28506, 830, 104, 3, 22, "Text"],
Cell[28613, 835, 117, 5, 62, "Input"],
Cell[28733, 842, 57, 0, 22, "Text"],
Cell[28793, 844, 88, 3, 28, "Input"],
Cell[28884, 849, 779, 14, 111, "Text"],
Cell[29666, 865, 217, 6, 96, "Input"],
Cell[29886, 873, 1845, 29, 477, "Subsubsection"],
Cell[31734, 904, 39, 0, 84, "Section"],
Cell[31776, 906, 473, 10, 120, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

