(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     55283,       1867]*)
(*NotebookOutlinePosition[     56323,       1902]*)
(*  CellTagsIndexPosition[     56279,       1898]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Cap\[IAcute]tulo 5
Manipulaci\[OAcute]n de Datos y Ajuste de Curvas\
\>", "Title"],

Cell[TextData[{
  "El presente cap\[IAcute]tulo tiene dos objetivos; el primero es el mostrar \
 como extraer, o almacenar, una serie de datos de archivos tipo ASCII, y el  \
segundo es manipular los datos e introducir las nociones de interpolaci\
\[OAcute]n y ajuste. En el primer ejemplo se utilizan datos almacenados en un \
archivo, concernientes al tiro parab\[OAcute]lico. Con estos datos se \
proponen funciones que ajusten de la mejor manera a estos datos. En el  \
segundo ejemplo existen datos de la dependencia del volumen con respecto a la \
temperatura para cierta cantidad de un gas. Teniendo esta \
informaci\[OAcute]n, se utiliza un procedimiento que incluye ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " para interpolar. Finalmente algunos de los resultados generados se \
almacenan en archivos tipo ASCII."
}], "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  FontColor->GrayLevel[0]],

Cell["Ajuste e Interpolaci\[OAcute]n", "Section"],

Cell["\<\
En muchas disciplinas experimentales se pueden obtener solo algunos \
resultados de un experimento en particular, esto se debe a que el obtener un \
resultado del experimento involucre bastante tiempo, que sea muy costoso, o \
que el material o las sustancias que se usen sean limitados, por mencionar \
algunos de los problemas con que se enfrenta un investigador experimental. \
Sin embargo, el hecho de que no se pueda tener un n\[UAcute]mero infinito de \
datos experimentales no siginifica que no se puedan hacer inferencias para \
predecir lo que va a acontecer en situaciones donde no se tienen reportados \
datos experimentales. De esta necesidad surgen los conceptos de interpolaci\
\[OAcute]n y ajuste, que permiten hacer inferencias de resultados \
experimentales, sin que estos se lleven a cabo. Siendo necesario, para \
realizar este objetivo, el contar con una serie de datos del mismo \
experimento cuyos valores est\[EAcute]n alrededor del valor deseado. \
\>", \
"Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[" Ajuste por m\[IAcute]nimos cuadrados", "Subsection"],

Cell[TextData[{
  "Sup\[OAcute]ngase que de manera experimental hemos determinado un conjunto \
de datos {(",
  Cell[BoxData[
      \(x\_i\)]],
  ",",
  Cell[BoxData[
      \(y\_i\)]],
  "): i=1,2,...,m} y deseamos saber la relaci\[OAcute]n funcional que existe \
entre las cantidades ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "y ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "que nos permita describir los aspectos cuantitativos del fen\[OAcute]meno  \
que estamos estudiando. El problema es encontrar la funci\[OAcute]n  m\
\[AAcute]s sencilla desde el punto de vista computacional, por ejemplo un  \
polinomio, que describa esta relaci\[OAcute]n funcional ",
  StyleBox["y=f(x),",
    FontSlant->"Italic"],
  " de una manera aproximada.\nEl m\[EAcute]todo de ",
  StyleBox["m\[IAcute]nimos cuadrados",
    FontWeight->"Bold"],
  " permite ",
  StyleBox["ajustar",
    FontWeight->"Bold"],
  " un polinomio algebraico de grado ",
  StyleBox["n<m-1, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(P\_n\)]],
  "(x)= ",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(i = 0\)\%n\)]],
  Cell[BoxData[
      \(a\_k\)]],
  Cell[BoxData[
      \(x\^k\)]],
  " a un conjunto de datos experimentales {(",
  Cell[BoxData[
      \(x\_i\)]],
  ",",
  Cell[BoxData[
      \(y\_i\)]],
  "):i=1,2,...,m}, de manera que \"",
  StyleBox["la suma de los cuadrados de las diferencias entre los valores \
experimentales  ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(y\_0\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(y\_1\)],
    FontSlant->"Italic"],
  StyleBox[",..., ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(y\_n\)],
    FontSlant->"Italic"],
  ",",
  StyleBox["  de ",
    FontWeight->"Bold"],
  StyleBox["y",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" y los correspondientes valores dados por el polinomio sea  m\
\[IAcute]nima\". ",
    FontWeight->"Bold"],
  " Para obtener este polinomio, es necesario seleccionar sus coeficientes ",
  Cell[BoxData[
      \(a\_0\)]],
  " , ",
  Cell[BoxData[
      \(a\_1\)]],
  ", ...,",
  Cell[BoxData[
      \(a\_n\)]],
  " de manera que sea m\[IAcute]nimo el error \n\t E(",
  Cell[BoxData[
      \(a\_0\)]],
  " , ",
  Cell[BoxData[
      \(a\_1\)]],
  ", ..., ",
  Cell[BoxData[
      \(a\_n\)]],
  ") = ",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(\([y\_i - P \((x\_i)\)]\)\^2\)]],
  " =\n\t\t= ",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(y\_i\%2\)]],
  " - 2",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(j = 0\)\%m\)]],
  Cell[BoxData[
      \(a\_j\)]],
  "(",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(y\_i\)]],
  Cell[BoxData[
      \(x\_i\%j\)]],
  ") + ",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(j = 0\)\%m\)]],
  Cell[BoxData[
      \(\[CapitalSigma]\_\(k = 0\)\%m\)]],
  Cell[BoxData[
      \(a\_i\)]],
  Cell[BoxData[
      \(a\_k\)]],
  "(",
  Cell[BoxData[
      \(\[Sum]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(x\_i\%\(j + k\)\)]],
  ").\nPara reducir al m\[IAcute]nimo esta funci\[OAcute]n de error E, es \
necesario que ",
  Cell[BoxData[
      \(\[PartialD]E\/\[PartialD]a\_j\)]],
  "=0, para cada j=0,1,2,...,n. Entonces para cada j,\n\t0 = ",
  Cell[BoxData[
      \(\[PartialD]E\/\[PartialD]a\_j\)]],
  " = -2 ",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(y\_i\)]],
  Cell[BoxData[
      \(x\_i\%j\)]],
  " + 2 ",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(k = 0\)\%n\)]],
  Cell[BoxData[
      \(\(a\_k\) \[CapitalSigma]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(x\_i\%\(j + k\)\)]],
  ".\nEsto nos da n+1 ecuaciones conocidas con el nombre de ",
  StyleBox["ecuaciones normales",
    FontWeight->"Bold"],
  " en las n+1 incognitas ",
  Cell[BoxData[
      \(a\_j\)]],
  ",\n \t",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(k = 0\)\%n\)]],
  Cell[BoxData[
      \(\(a\_k\) \[CapitalSigma]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(x\_i\%\(j + k\)\)]],
  " = ",
  Cell[BoxData[
      \(\[CapitalSigma]\_\(i = 1\)\%m\)]],
  Cell[BoxData[
      \(y\_i\)]],
  Cell[BoxData[
      \(x\_i\%j\)]],
  ",        j=0,1,2..., n.\n Este sistema tiene una \[UAcute]nica soluci\
\[OAcute]n si los valores experimentales ",
  Cell[BoxData[
      \(x\_1\)]],
  " , ",
  Cell[BoxData[
      \(x\_2\)]],
  ", ..., ",
  Cell[BoxData[
      \(x\_n\)]],
  " son distintos entre si."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[" F\[OAcute]rmula de interpolaci\[OAcute]n de Lagrange", "Subsection"],

Cell[TextData[{
  " Ahora sup\[OAcute]ngase que en lugar de ",
  StyleBox["ajustar",
    FontWeight->"Bold"],
  " un polinomio a los datos experimentales minimizando un cierto error, \
deseamos encontrar un polinomio de grado a lo m\[AAcute]s n tal que sus \
valores en los puntos ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["x",
          FontSlant->"Italic"], "0"]]],
  ",",
  Cell[BoxData[
      \(\(\(\ \)\(x\_1\)\)\)],
    FontSlant->"Italic"],
  StyleBox[" , ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(x\_2\)],
    FontSlant->"Italic"],
  StyleBox[", ..., ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(x\_n\)],
    FontSlant->"Italic"],
  ", coincidan con los valores medidos de ",
  StyleBox["y; ",
    FontSlant->"Italic"],
  Cell[BoxData[
      SubscriptBox[
        StyleBox["y",
          FontSlant->"Italic"], "0"]]],
  ",",
  StyleBox["  ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(y\_1\)],
    FontSlant->"Italic"],
  StyleBox[",..., ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(y\_n\)],
    FontSlant->"Italic"],
  ", es decir:\n\t ",
  Cell[BoxData[
      \(y\_0\)]],
  " = P(",
  Cell[BoxData[
      \(x\_0\)]],
  "), ",
  Cell[BoxData[
      \(y\_1\)]],
  " = P(",
  Cell[BoxData[
      \(x\_1\)]],
  "), ..., ",
  Cell[BoxData[
      \(y\_n\)]],
  " = P(",
  Cell[BoxData[
      \(x\_n\)]],
  ").\nEste polinomio tambi\[EAcute]n describir\[AAcute] de manera  \
aproximada la dependencia funcional entre ",
  StyleBox["y",
    FontSlant->"Italic"],
  " y ",
  StyleBox["x",
    FontSlant->"Italic"],
  " en los intervalos donde no se realizaron mediciones. El polinomio  \
obtenido por este m\[EAcute]todo se llama ",
  StyleBox["polinomio interpolado",
    FontWeight->"Bold"],
  " y este m\[EAcute]todo para obtener la variaci\[OAcute]n aproximada de ",
  StyleBox["y",
    FontSlant->"Italic"],
  " como funci\[OAcute]n de ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", se llama ",
  StyleBox["interpolaci\[OAcute]n.",
    FontWeight->"Bold"],
  "\nPara obtener este polinomio, sup\[OAcute]ngase que tiene la forma \n\t \
P(x) = ",
  Cell[BoxData[
      \(c\_0\)]],
  "(x-",
  Cell[BoxData[
      \(x\_1\)]],
  ")(x-",
  Cell[BoxData[
      \(x\_2\)]],
  ")...(x-",
  Cell[BoxData[
      \(x\_n\)]],
  ") +\n\t\t",
  Cell[BoxData[
      \(c\_1\)]],
  "(x-",
  Cell[BoxData[
      \(x\_0\)]],
  ")(x-",
  Cell[BoxData[
      \(x\_2\)]],
  ")...(x-",
  Cell[BoxData[
      \(x\_n\)]],
  ") +...+\n\t\t",
  Cell[BoxData[
      \(c\_n\)]],
  "(x-",
  Cell[BoxData[
      \(x\_0\)]],
  ")(x-",
  Cell[BoxData[
      \(x\_1\)]],
  ")...(x-",
  Cell[BoxData[
      \(x\_\(n - 1\)\)]],
  "),                    (1)\nlos coeficientes ",
  Cell[BoxData[
      \(c\_0\)]],
  ", ",
  Cell[BoxData[
      \(c\_1\)]],
  ",..., ",
  Cell[BoxData[
      \(c\_n\)]],
  " deben calcularse de manera que \n\t",
  Cell[BoxData[
      \(y\_0\)]],
  " = P(",
  Cell[BoxData[
      \(x\_0\)]],
  "), ",
  Cell[BoxData[
      \(y\_1\)]],
  " = P(",
  Cell[BoxData[
      \(x\_1\)]],
  "), ..., ",
  Cell[BoxData[
      \(y\_n\)]],
  " = P(",
  Cell[BoxData[
      \(x\_n\)]],
  ").          (2)\nEn (1) t\[OAcute]mese x = ",
  Cell[BoxData[
      \(x\_0\)]],
  "; entonces, tomando en cuenta (2), obtenemos \n\t",
  Cell[BoxData[
      \(c\_0\)]],
  " = ",
  Cell[BoxData[
      \(y\_0\/\(\(\((x\_0 - x\_1)\) \((x\_0 - x\_2)\) ... \) \((x\_0 - \
x\_n)\)\)\)]],
  ".\nY de manera similar se obtiene,\n\t",
  Cell[BoxData[
      \(c\_1\)]],
  " = ",
  Cell[BoxData[
      \(y\_1\/\(\(\((x\_1 - x\_0)\) \((x\_1 - x\_2)\) ... \) \((x\_1 - \
x\_n)\)\)\)]],
  ",\n\t",
  Cell[BoxData[
      \(c\_2\)]],
  " = ",
  Cell[BoxData[
      \(\(\(y\_2\/\(\(\((x\_2 - x\_0)\) \((x\_2 - x\_1)\) \((x\_2 - 
                    x\_3)\) ... \) \((x\_2 - x\_n)\)\)\)\(,\)\)\)]],
  "\n\t...\n\t",
  Cell[BoxData[
      \(c\_n\)]],
  " = ",
  Cell[BoxData[
      \(y\_n\/\(\(\((x\_n - x\_0)\) \((x\_n - x\_1)\) ... \) \((x\_n - x\_\(n \
- 1\))\)\)\)]],
  ".\nSustituyendo estos valores en (1) obtenemos que \n\tP(x) = ",
  Cell[BoxData[
      \(\(\(\((x - x\_1)\) \((x - x\_2)\) ... \) \((x - \
x\_n)\)\)\/\(\(\((x\_0 - x\_1)\) \((x\_0 - x\_2)\) ... \) \((x\_0 - x\_n)\)\)\
\)]],
  Cell[BoxData[
      \(y\_0\)]],
  " + \n\t\t+ ",
  Cell[BoxData[
      \(\(\(\((x - x\_0)\) \((x - x\_2)\) ... \) \((x - \
x\_n)\)\)\/\(\(\((x\_1 - x\_0)\) \((x\_1 - x\_2)\) \((x\_1 - x\_3)\) ... \) \
\((x\_1 - x\_n)\)\)\)]],
  Cell[BoxData[
      \(y\_1\)]],
  " +...+\n\t\t+",
  Cell[BoxData[
      \(\(\(\((x - x\_0)\) \((x - x\_1)\) ... \) \((x - x\_\(n - 1\))\)\)\/\(\
\(\((x\_n - x\_0)\) \((x\_n - x\_1)\) ... \) \((x\_n - x\_\(n - 1\))\)\)\)]],
  Cell[BoxData[
      \(y\_n\)]],
  " .\nEsta f\[OAcute]rmula se conoce como ",
  StyleBox["f\[OAcute]rmula de interpolaci\[OAcute]n de Lagrange.",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  " A continuaci\[OAcute]n se usar\[AAcute]n las t\[EAcute]cnicas con que \
cuenta ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " para obtener ajustes e interpolaciones, en ejemplos ampliamente conocidos \
y as\[IAcute] concluir si estas t\[EAcute]cnicas son confiables. Ya que los \
datos experimentales que se usar\[AAcute]n en este cap\[IAcute]tulo se \
encuentran en el disco que viene incluido con el libro, es recomendable \
trabajar en este directorio, para esto se debe utilizar"
}], "Text"],

Cell[BoxData[
    \(\(SetDirectory["\<c:\Simulacion\>"];\)\)], "Input",
  CellLabel->"In[20]:=",
  PageWidth->Infinity,
  TextAlignment->Left,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["\<\
Dentro de este directorio se puede saber que archivos existen con \
la instrucci\[OAcute]n\
\>", "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(FileNames[{"\<*.*\>"}]\)], "Input",
  CellLabel->"In[21]:="],

Cell["\<\
o si se est\[AAcute] interesado solamente en los archivos con \
extensi\[OAcute]n dat se debe de usar\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(FileNames[{"\<*.dat\>"}]\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
As\[IAcute] como estas instrucciones, existen algunas m\[AAcute]s \
para la manipulaci\[OAcute]n de archivos.\
\>", "Text"],

Cell["Tiro Parab\[OAcute]lico", "Section"],

Cell[TextData[{
  "Un problema muy conocido en los cursos f\[IAcute]sica b\[AAcute]sica es el \
del tiro parab\[OAcute]lico. En el archivo ejem1.dat se tienen treinta \
valores del tiempo, y a cada valor de \[EAcute]ste le corresponden las \
coordenadas {",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "} de un m\[OAcute]vil. Lo primero que se puede hacer es corroborar que \
efectivamente se tienen estos datos con el comando ",
  StyleBox["!!nombre",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", donde ",
  StyleBox["nombre",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " representa el nombre del archivo en que se encuentran los datos de inter\
\[EAcute]s."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["!!ejem1.dat", "Input",
  CellLabel->"In[4]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  "Se puede observar que se tienen tres columnas, en la primera se tiene el \
tiempo, en la segunda la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " y en la tercera la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " del m\[OAcute]vil. Para poder extraer estos datos es necesario accesar el \
archivo, entendiendo que solo se est\[AAcute] interesado en leerlo y que no \
se le quiere modificar. Esto se puede conseguir con el comando ",
  StyleBox["OpenRead,",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " adem\[AAcute]s es necesario crear una variable que permita extraer estos  \
datos, en este caso se utilizar\[AAcute] la variable ",
  StyleBox["lectura",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["lectura=OpenRead[\"ejem1.dat\"];", "Input",
  CellLabel->"In[5]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "En este momento ya se puede accesar a cualquier cantidad usando esta \
variable, y como se sabe que el archivo contiene tres columnas y cada rengl\
\[OAcute]n representa la posici\[OAcute]n del m\[OAcute]vil en un tiempo \
dado, se utilizar\[AAcute] ",
  StyleBox["ReadList",
    FontWeight->"Bold"],
  " para leer esta lista de datos y la opci\[OAcute]n ",
  StyleBox["{Number,Number,Number}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " para indicar que se tienen tres columnas de n\[UAcute]meros. Esta partici\
\[OAcute]n se asignar\[AAcute] a la variable ",
  StyleBox["experimento",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["experimento=ReadList[lectura,{Number,Number,Number}];", "Input",
  CellLabel->"In[6]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "Ya que se han extra\[IAcute]do los datos, es importante cerrar el archivo \
con el comando ",
  StyleBox["Close",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["Close[lectura];", "Input",
  CellLabel->"In[7]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "Por la manera en que se realiz\[OAcute] la lectura, la variable ",
  StyleBox["experimento",
    FontWeight->"Bold"],
  " est\[AAcute] compuesta de varios elementos. Cada elemento est\[AAcute] \
formado por tres cantidades, {",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "}. A manera de ejemplo, si se est\[AAcute] interesado en el primer \
elemento de la variable ",
  StyleBox["experimento",
    FontWeight->"Bold"],
  " hay que utilizar"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(experimento[\([1]\)]\)], "Input",
  CellLabel->"In[8]:="],

Cell[TextData[{
  "Comparando el resultado anterior y lo que se obtuvo con la instrucci \
\[OAcute]n ",
  StyleBox["!!ejem1.dat",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " se puede estar tranquilo con respecto a la manera en que se accesaron los \
 datos, debido a  que lo que se encuentra en ",
  StyleBox["experimento[[1]]",
    FontWeight->"Bold"],
  " coincide con la primer l\[IAcute]nea del archivo ejem1.dat."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Ejercicio 1:",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\n(",
    FontWeight->"Bold"],
  "a) ",
  StyleBox[" ",
    FontWeight->"Bold"],
  "\[DownQuestion]Cu\[AAcute]les son los valores que componen el elemento 10  \
de la variable experimento?\n(b) \[DownQuestion]Cu\[AAcute]les son los \
valores  que componen el elemento 23 de la variable experimento?"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "En este ejemplo se sabe que hay treinta elementos en la variable ",
  StyleBox["experimento",
    FontWeight->"Bold"],
  ", sin embargo no es necesario que se haya mencionado esto desde un inicio  \
ya que se puede obtener esta informaci\[OAcute]n utilizando ",
  StyleBox["Dimensions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Dimensions[experimento]", "Input",
  CellLabel->"In[9]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  "Este comando indica el n\[UAcute]mero de elementos y la cantidad de  \
valores que forman cada elemento, en este caso se tienen treinta elementos  \
con tres valores cada uno. Al igual que ",
  StyleBox["experimento[[1]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " proporcion\[OAcute] el elemento 1,"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["experimento[[1,3]]", "Input",
  CellLabel->"In[10]:=",
  PageWidth->Infinity],

Cell["\<\
proporciona el tercer valor del primer elemento. Sin embargo, al \
escribir\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["experimento[[1,4]]", "Input",
  CellLabel->"In[11]:=",
  PageWidth->Infinity],

Cell["\<\
no se tendr\[AAcute] informaci\[OAcute]n alguna debido a  que el \
cuarto valor del primer elemento no existe. Por lo tanto, cuando se est\
\[AAcute]n manipulando datos extra\[IAcute]dos de alg\[UAcute]n archivo, en \
todo momento se debe de tener presente las dimensiones del problema que se \
est\[AAcute] tratando.\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "En principio se puede extraer cualquier valor de cualquier elemento, en  \
particular se tiene inter\[EAcute]s de formar las parejas {",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "} y {",
  Cell[BoxData[""], "Input"],
  Cell[BoxData[""], "Input"],
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "}, ya que esto indica como var\[IAcute]a cada una de las coordenadas con  \
respecto al tiempo. Para esto hay que usar el comando ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
exis=Table[{experimento[[i,1]],experimento[[i,2]]},{i,30}];
yes=Table[{experimento[[i,1]],experimento[[i,3]]},{i,30}];\
\>", "Input",
  CellLabel->"In[12]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "Como puede verse, la variable ",
  StyleBox["exis",
    FontWeight->"Bold"],
  " est\[AAcute] formada por las parejas de los datos de la primera y segunda \
columna. Y la variable ",
  StyleBox["yes",
    FontWeight->"Bold"],
  " tiene asignados los datos de la primera y tercera columna. Por supuesto \
que cada una de esta variables se puede graficar."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["An\[AAcute]lisis de la Coordenada x", "Subsection"],

Cell[TextData[{
  "A continuaci\[OAcute]n se har\[AAcute] un an\[AAcute]lisis de lo que \
acontece con la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", aunque se sabe de antemano que se tiene un movimiento rectil\[IAcute]neo \
uniforme.\nPara visualizar una serie de datos se utiliza el comando ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Entonces para graficar los puntos formados por las parejas que se \
encuentran en la variable ",
  StyleBox["exis",
    FontWeight->"Bold"],
  " se debe de usar"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
g1=ListPlot[exis,PlotStyle->{PointSize[0.02]},
  AxesLabel->{\"tiempo\",\"x\"}];\
\>", "Input",
  CellLabel->"In[14]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  "En este caso se ha usado un tama\[NTilde]o de punto igual a 0.02 para  \
resaltar cada uno de los datos. Evidentemente, la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " var\[IAcute]a linealmente con el tiempo. Afortunadamente no solo se puede \
 limitar a un  an\[AAcute]lisis gr\[AAcute]fico, ya que se pueden ajustar  \
estos datos a una funci\[OAcute]n con el comando ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["x=Fit[exis,{1,t},t]", "Input",
  CellLabel->"In[15]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  "El comando ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " requiere de tres argumentos: datos a ajustar, forma de la funci\[OAcute]n \
 a ajustar y variable a utilizar. En este caso se ha impuesto el ajuste a \
trav \[EAcute]s de una funci\[OAcute]n lineal, por esta raz\[OAcute]n el \
segundo  argumento de ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " es de la forma {1,t} para obtener el t\[EAcute]rmino independiente y la  \
pendiente de la recta.  De esta manera la variable ",
  StyleBox["x",
    FontWeight->"Bold"],
  " contiene el ajuste de la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " como funci\[OAcute]n del tiempo. En el caso de que se est\[EAcute]  \
interesado en un valor de x a un determinado tiempo, en particular cuando ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=0, se debe de emplear"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["x /. t->0", "Input",
  CellLabel->"In[16]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  StyleBox["Ejercicio 2:",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\nPara los siguientes valores del tiempo encontrar los  correspondientes \
valores de ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".\na. ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=0.25\nb. ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=0.55"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Tambi\[EAcute]n se puede obtener la curva trazada en ",
  StyleBox["g1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", pero usando el ajuste propuesto."
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["g2=Plot[x,{t,0,1}];", "Input",
  CellLabel->"In[17]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["\<\
Comparando el ajuste y los datos obtenidos del archivo se tendr\
\[AAcute].\
\>", "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Show[g1,g2];", "Input",
  CellLabel->"In[18]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["\<\
Indudablemente el ajuste que se tiene es adecuado, sin embargo no \
en todos los casos se puede obtener lo mismo, en general encontrar el ajuste \
perfecto es una tarea dif\[IAcute]cil.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "A partir de aqu\[IAcute] se puede manipular el ajuste ",
  StyleBox["x",
    FontWeight->"Bold"],
  " de la manera que m\[AAcute]s convenga. Por ejemplo, en la variable ",
  StyleBox["velx",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " se asignar\[AAcute] la derivada de ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " con respecto al tiempo."
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["velx=D[x,t]", "Input",
  CellLabel->"In[19]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  "De aqu\[IAcute] se puede concluir que el moviento a lo largo de la  \
coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " es uniforme, ya que se ha obtenido una velocidad constante."
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["An\[AAcute]lisis de la Coordenada y", "Subsection"],

Cell[TextData[{
  "Para analizar que tipo de movimiento se presenta en la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", es necesario seguir los pasos que se hicieron en el caso anterior."
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Primero se ontedr\[AAcute] el comportamiento de la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " con respecto al tiempo."
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
g3=ListPlot[yes,PlotStyle->{PointSize[0.02]},
  AxesLabel->{\"tiempo\",\"y\"}];\
\>", "Input",
  CellLabel->"In[20]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "A diferencia de la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", la gr\[AAcute]fica anterior sugiere un ajuste cuadr\[AAcute]tico."
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["y=Fit[yes,{1,t,t^2},t]", "Input",
  CellLabel->"In[21]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "De aqu\[IAcute] que el valor inicial de ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " ser\[AAcute]"
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["y /. t->0", "Input",
  CellLabel->"In[22]:=",
  PageWidth->Infinity],

Cell["y la gr\[AAcute]fica del ajuste es", "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["g4=Plot[y,{t,0,1}];", "Input",
  CellLabel->"In[23]:=",
  PageWidth->Infinity],

Cell["\<\
Para saber que tan bueno fue el ajuste propuesto, se hace la \
comparaci\[OAcute]n con los datos obtenidos del archivo\
\>", "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Show[g3,g4];", "Input",
  CellLabel->"In[24]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "Al igual que el an\[AAcute]lisis realizado en la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", el ajuste propuesto para la coordenada ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " es excelente.\nNuevamente, la manipulaci\[OAcute]n de este ajuste ser \
\[AAcute] id\[EAcute]ntico al realizado anteriormente, asignando la derivada  \
de ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " con respecto a ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", a la variable ",
  StyleBox["vely",
    FontWeight->"Bold"],
  "."
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["vely=D[y,t]", "Input",
  CellLabel->"In[25]:=",
  PageWidth->Infinity],

Cell["Teniendo que al tiempo cero", "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(vely\  /. \ t -> 0\)], "Input",
  CellLabel->"In[26]:="],

Cell[TextData[{
  "En este caso la velocidad depende en forma lineal con respecto al tiempo,  \
lo cual significa que el movimiento en ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " es uniformemente acelerado. Adem\[AAcute]s, se puede obtener en que valor \
 de ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " la derivada se anula"
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["tmax=Solve[vely==0,t]", "Input",
  CellLabel->"In[27]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "y evaluar el valor de ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " en este tiempo. Asignando primero el valor del tiempo obtenido a la  \
variable ",
  StyleBox["tiempo",
    FontWeight->"Bold"],
  " "
}], "Text",
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(tiempo = t\  /. \ tmax[\([1]\)]\)], "Input",
  CellLabel->"In[28]:="],

Cell["para finalizar con la evaluaci\[OAcute]n", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(ymaxima = y\  /. t -> tiempo\)], "Input",
  CellLabel->"In[29]:="],

Cell[TextData[{
  "De esta manera se ha encontrado el valor m\[AAcute]ximo de la coordenada \
",
  StyleBox["y",
    FontSlant->"Italic"],
  ", y el tiempo donde se alcanza esto."
}], "Text"],

Cell[TextData[{
  StyleBox["Ejercicio 3",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\nVerificar que en ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=",
  StyleBox["tiempo",
    FontWeight->"Bold"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " tiene un valor m\[AAcute]ximo."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Ejercicio 4",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\nObtener un ajuste  adicional a partir de ",
  StyleBox["otray",
    FontWeight->"Bold"],
  "=",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["[yes,{t,t^2},t]",
    FontWeight->"Bold"],
  " y comparar los resultados obtenidos con el ajuste obtenido a  trav\
\[EAcute]s de la variable ",
  StyleBox["y",
    FontWeight->"Bold"],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Ejercicio 5",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\n(a) Formar las parejas de datos {",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "}.\n(b) Realizar el ajuste m\[AAcute]s apropiado a las parejas de puntos  \
formadas en el inciso a.\n(c) Hacer una gr\[AAcute]fica del ajuste obtenido  \
en el inciso anterior. Si se tiene un m\[AAcute]ximo, encontrar el valor de  \
la pareja {xmax,ymax} de ese punto. \t\t"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Gases Reales", "Section"],

Cell["\<\
En el archivo ejem2.dat hay datos experimentales de presi\[OAcute]n \
y volumen obtenidos para un mol de un gas real. Recordar que para ver lo que \
se encuentra en el archivo ejem2.dat hay que ejecutar\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["!!ejem2.dat", "Input",
  CellLabel->"In[30]:=",
  PageWidth->Infinity],

Cell["\<\
se observa que las primeras dos l\[IAcute]neas tienen caracteres \
diferentes de n\[UAcute]meros. As\[IAcute] que para poder leer este archivo \
es necesario tomar en cuenta esta informaci\[OAcute]n. Primero hay que abrir \
el archivo para poder leer los datos.\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(gas1 = OpenRead["\<ejem2.dat\>"];\)\)], "Input",
  CellLabel->"In[37]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  "Debido a que las dos primeras l\[IAcute]neas no son \[UAcute]tiles para el \
 an\[AAcute]lisis que se va a realizar  se saltar\[AAcute]n utilizando el  \
comando ",
  StyleBox["Skip",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Skip[gas1,Record,2]", "Input",
  CellLabel->"In[38]:="],

Cell[TextData[{
  "con esto se pueden leer ahora las dos columnas de n\[UAcute]meros,  \
asignando este arreglo a la  variable ",
  StyleBox["listagas",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["listagas=ReadList[gas1,{Number,Number}];", "Input",
  CellLabel->"In[39]:="],

Cell["finalmente se debe de cerrar el archivo.", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Close[gas1];", "Input",
  CellLabel->"In[40]:="],

Cell[TextData[{
  StyleBox["Ejercicio 6",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\n(a) \[DownQuestion]De cu\[AAcute]ntos elementos consta la  lista de \
valores ",
  StyleBox["listagas",
    FontWeight->"Bold"],
  "?\n(b) \[DownQuestion]Qu\[EAcute] valores tiene el d\[EAcute]cimo  \
elemento?"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Como ya se tienen formados los pares {",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "}, se puede generar la gr\[AAcute]fica de  presi\[OAcute]n contra volumen"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
g5=ListPlot[listagas,Prolog->PointSize[0.02],
  AxesLabel->{\"v\",\"p\"}];\
\>", "Input",
  CellLabel->"In[41]:="],

Cell["\<\
En este caso el ajuste de la curva ser\[AAcute] m\[AAcute]s dif\
\[IAcute]cil con respecto al caso del tiro parab\[OAcute]lico ya que la forma \
de la gr\[AAcute]fica es complicada. Por ejemplo, un ajuste de un polinomio \
de cuarto grado tendr\[AAcute] la forma\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["presion=Fit[listagas,{1,v,v^2,v^3,v^4},v]", "Input",
  CellLabel->"In[42]:="],

Cell["y la gr\[AAcute]fica asociada a este ajuste ser\[AAcute]", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["g6=Plot[presion,{v,0,0.4},AxesLabel->{\"v\",\"p\"}];", "Input",
  CellLabel->"In[43]:="],

Cell["\<\
Al comparar este ajuste con los datos experimentales se tendr\
\[AAcute]\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Show[g5,g6];", "Input",
  CellLabel->"In[44]:="],

Cell[TextData[{
  "Por supuesto que este ajuste no tiene nada que ver con el comportamiento  \
de  los datos experimentales. Sin embargo, con un conocimiento m\[AAcute]s  \
profundo del problema que se est\[AAcute] tratando se puede llegar a proponer \
 una forma del polinomio m\[AAcute]s adecuada. Por otro lado, si se est \
\[AAcute] interesado solamente en valores de la presi\[OAcute]n que no  \
corresponden a los datos experimentales y no en la forma expl\[IAcute]cita de \
 la funci\[OAcute]n que mejor ajusta, se debe de utlizar el comando ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["fap=Interpolation[listagas]", "Input",
  CellLabel->"In[45]:="],

Cell[TextData[{
  "Con este comando se tiene una interpolaci\[OAcute]n de los datos  \
experimentales, teniendo como salida en pantalla los valores m\[IAcute]nimo y \
 m\[AAcute]ximo del volumen. De esta manera se puede tener el valor de la  \
presi\[OAcute]n para cualquier valor del volumen.\nEn particular para un  \
volumen ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  "=0.0412 L se tendr\[AAcute]"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["fap[0.0412]", "Input",
  CellLabel->"In[46]:="],

Cell[TextData[{
  "A diferencia del comando ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", en esta ocasi\[OAcute]n solamente se pueden manejar  valores del volumen \
 que se encuentren en el rango de los valores experimentales. Respetando esta \
 restricci\[OAcute]n se puede generar la respectiva gr\[AAcute]fica"
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["g7=Plot[fap[v],{v,0.04,0.54}];", "Input",
  CellLabel->"In[47]:="],

Cell["\<\
Comparando el ajuste con los datos experimentales se observa que se \
tiene una mejor representaci\[OAcute]n del comportamiento de la \
presi\[OAcute]n como funci\[OAcute]n del volumen.\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["Show[g5,g7];", "Input",
  CellLabel->"In[48]:="],

Cell[TextData[{
  StyleBox["Ejercicio 7",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\n(a) Graficar la presi\[OAcute]n con respecto al volumen  para valores de \
",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " entre 0.1 L y 0.2 L.\n(b) Para los valores del volumen considerados en el \
 inciso anterior, realizar un ajuste con un polinomio de grado dos, y \
comparar  con el ajuste obtenido por el comando ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n(c) En ciertos procesos termodin\[AAcute]micos el trabajo realizado por \
 un gas que se expande o el trabajo realizado sobre \[EAcute]ste cuando se  \
comprime, se puede obtener al evaluar la integral ",
  Cell[BoxData[
      RowBox[{"-", 
        RowBox[{
          StyleBox[\(\[Integral]\_\(V\_i\)\%\(V\_f\)\),
            ScriptLevel->0], 
          RowBox[{"p", 
            StyleBox["\[ThinSpace]",
              ScriptLevel->0], 
            StyleBox[\(\[DifferentialD]V\),
              ScriptLevel->0]}]}]}]]],
  ". Evaluar num\[EAcute]ricamente esta integral para una expansi\[OAcute]n  \
que realiza el gas de ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "=0.142 L a ",
  Cell[BoxData[
      \(TraditionalForm\`v\_f\)]],
  "=0.327 L."
}], "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["Alamacenamiento de Datos en Formato ASCII", "Section"],

Cell[TextData[{
  "Hasta ahora se han le\[IAcute]do solamente los datos que existen en  \
archivos generados previamente. Sin embargo, tambi\[EAcute]n se pueden  \
generar dentro de ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " archivos tipo ASCII y en ellos escribir los resultados obtenidos en una  \
sesi\[OAcute]n. El tener archivos tipo ASCII significa que se almacenar \
\[AAcute]n caracteres simples como un n\[UAcute]mero o una letra, pero de  \
ninguna manera se podr\[AAcute]n almacenar s\[IAcute]mbolos complejos como el \
 de una integral.\nAnalizando detenidamente el archivo ejem1.dat resulta que  \
se tienen incrementos de 0.1 segundos en el tiempo. Sin embargo, si se est \
\[AAcute] interesado en las coordenadas {",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "} en el intervalo de tiempo [1.6,2.2] con incrementos de 0.05 segundos, es \
 necesario recurrir a la interpolaci\[OAcute]n. Hay que recordar que se puede \
 obtener el valor de {",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "} a cualquier tiempo debido a que se tienen las interpolaciones de las dos \
 coordenadas en las variables ",
  StyleBox["x",
    FontWeight->"Bold"],
  " y ",
  StyleBox["y",
    FontWeight->"Bold"],
  ". Por lo tanto, para ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "=1.6 s, se tendr\[AAcute]"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
Print[PaddedForm[1.6,{4,2}],PaddedForm[x /. t->1.6,{6,3}],
 PaddedForm[y /. t->1.6,{6,3}]]\
\>", "Input",
  CellLabel->"In[49]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "En este caso se han impreso las tres variables t,x,y, teniendo la variable \
 t un campo de 4 caracteres y justo antes de las dos \[UAcute]ltimas cifras \
se  ha puesto el punto decimal, pero para las restantes variables se tiene un \
 campo de 6 caracteres con tres cifras decimales. El proceso de asignar \
cierto  n\[UAcute]mero de cifras en la impresi\[OAcute]n de un n\[UAcute]mero \
se le  conoce como formateo.\nDesafortunadamente se han podido imprimir las  \
variables en una sola ocasi\[OAcute]n, pero hay que recordar que se est \
\[AAcute] interesado en varios de estos valores. Para lograr esto se utiliza  \
una instrucci\[OAcute]n que permite repetir una instrucci\[OAcute]n tantas  \
veces como se desee. Esta instrucci\[OAcute]n es\n\t",
  StyleBox["Do[expresi\[OAcute]n,{iterador,inicio,final}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\nComo se observa en la sintaxis, la expresi\[OAcute]n dentro de ",
  StyleBox["Do",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " se ejecutar\[AAcute] dependiendo de los valores que tome el iterador. As \
\[IAcute] la instrucci\[OAcute]n "
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Do[Print[\"Hola\"],{i,3,7}]", "Input",
  CellLabel->"In[50]:=",
  PageWidth->Infinity],

Cell["\<\
imprime Hola cuatro veces, ya que el iterador i toma solo cuatro \
valores.\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
Si se est\[AAcute] interesado en que el tiempo comience en 1.6 s y \
que termine en 1.7 s tomando intervalos de 0.05 segundos se \
tendr\[AAcute]\
\>", "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
inicio=1.6;
Do[tiempo=inicio+0.05*(i-1);
   Print[PaddedForm[tiempo,{4,2}],
     PaddedForm[x /. t->tiempo,{6,3}],
     PaddedForm[y /. t->tiempo,{6,3}]],
   {i,1,3}]\
\>", "Input",
  CellLabel->"In[51]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "para el intervalo ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(\ \)\)\)]],
  "\[Epsilon] [1.6,2.2] el iterador debe de tomar 13 valores"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
inicio=1.6;
Do[tiempo=inicio+0.05*(i-1);
   Print[PaddedForm[tiempo,{4,2}],
     PaddedForm[x /. t->tiempo,{6,3}],
     PaddedForm[y /. t->tiempo,{6,3}]],
  {i,1,13}]\
\>", "Input",
  CellLabel->"In[53]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[{
  "Ahora ya se han generado los valores en el intervalo deseado, pero el  \
objetivo final es poder escribirlos en un archivo. Con esta finalidad se  \
crear\[AAcute] el archivo ejem3.dat con la instrucci\[OAcute]n ",
  StyleBox["OpenWrite",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["archivo=OpenWrite[\"ejem3.dat\",FormatType->OutputForm];", "Input",
  CellLabel->"In[55]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "De esta manera se ha abierto el archivo ejem3.dat para poder escribir  \
dentro de \[EAcute]ste, y se ha usado la opci\[OAcute]n ",
  StyleBox["FormatType->OutputForm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " para escribir con cualquier formato que se desee. Ya que se van a  \
escribir tres columnas, lo primero que se har\[AAcute] es asignar un  \
encabezado, utilizando para esto el comando ",
  StyleBox["Write",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Write[archivo,\"  t(s)    x(m)    y(m)\"];", "Input",
  CellLabel->"In[56]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "Con esta instrucci\[OAcute]n se ha direccionado la escritura de t(s)  x(m) \
  y(m) al archivo ejem4.dat a trav\[EAcute]s de la variable ",
  StyleBox["archivo",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Finalmente para escribir las tres columnas se debe de usar"
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["\<\
inicio=1.6;
Do[tiempo=inicio+0.05*(i-1);
   Write[archivo,
     PaddedForm[tiempo,{4,2}],
     PaddedForm[x /. t->tiempo,{6,3}],
     PaddedForm[y /. t->tiempo,{6,3}]],
  {i,1,13}]\
\>", "Input",
  CellLabel->"In[57]:=",
  PageWidth->Infinity],

Cell[TextData[{
  "Como puede notarse, se ha cambiado la instrucci\[OAcute]n ",
  StyleBox["Print",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " por la instrucci\[OAcute]n ",
  StyleBox["Write",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", con lo que no se observa ning\[UAcute]n resultado ya que la escritura se \
 di\[OAcute] en el archivo de inter\[EAcute]s. Debido que ya no se escribir \
\[AAcute]n m\[AAcute]s datos en el archivo, es necesario cerrarlo."
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Close[archivo];", "Input",
  CellLabel->"In[59]:=",
  PageWidth->Infinity],

Cell[BoxData[{
    StyleBox[\(Ejercicio\ 8\),
      FontWeight->"Bold",
      FontSlant->"Italic"], "\[IndentingNewLine]", 
    RowBox[{\(\((a)\)\ Verificar\ que\ el\ archivo\ ejem3 . 
          dat\ tiene\ los\ datos\ correctos\ y\ en\ el\ formato\ deseado . \
\[IndentingNewLine]\((b)\)\ Generar\ el\ archivo\ ejem4 . dat\), ",", 
      RowBox[{
      "y", " ", "dentro", " ", "de", " ", "este", " ", "archivo", " ", 
        "escribir", " ", "el", " ", "valor", " ", "de", " ", "la", " ", 
        "funci\[OAcute]n", " ", "seno", " ", "para", " ", "valores", " ", 
        "de", " ", "su", " ", "argumento", 
        " ", \(entre\ [\(-\[Pi]\), \[Pi]]\), " ", "en", " ", "intervalos", 
        " ", "de", 
        RowBox[{
          FormBox[\(\[Pi]\/180\),
            "TraditionalForm"], "."}]}]}]}], "Text",
  TextAlignment->Left,
  TextJustification->0,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  StyleBox["Ejercicio 9",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\nEn el siguiente ejercicio use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " s\[OAcute]lo en caso necesario. Considere la siguiente lista de pares  \
ordenados (x, y):\n ",
  Cell[BoxData[
      TagBox[GridBox[{
            {"\<\"x\"\>", "\<\"y\"\>"},
            {
              StyleBox["0.2`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], 
              StyleBox["0.0504459999999999997`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["0.3`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], 
              StyleBox["0.098426000000000009`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["0.6`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], 
              StyleBox["0.33277000000000001`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["0.9`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], 
              StyleBox["0.726600000000000001`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["1.10000000000000008`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], 
              StyleBox["1.09719999999999995`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["1.30000000000000004`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], 
              StyleBox["1.56970000000000009`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["1.39999999999999991`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], 
              StyleBox["1.8487`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["1.60000000000000008`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2], 
              StyleBox["2.50150000000000005`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        (TableForm[ #, TableHeadings -> {None, {"x", "y"}}]&)]], "Output"],
  "\n(a) Grafique la lista de datos y ajuste un polinomio de grado dos.\n(b)  \
Suponga que ",
  StyleBox["x",
    FontWeight->"Bold"],
  " y ",
  StyleBox["y ",
    FontWeight->"Bold"],
  "satisfacen una",
  StyleBox[" ",
    FontWeight->"Bold"],
  "relaci\[OAcute]n",
  StyleBox[" ",
    FontWeight->"Bold"],
  "exponencial del tipo",
  StyleBox[" y = b",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(\(\(\ \)\(e\^\(\(a\)\(\ \)\(x\)\(\ \)\)\)\)\)],
    FontWeight->"Bold"],
  ", es decir  ",
  StyleBox["lny = ln b + a x",
    FontWeight->"Bold"],
  "  Elabore una lista de pares ordenados (x, ln (y)). Grafique esta nueva  \
lista y ajuste un polinomio lineal a estos datos.\n(c) El t\[EAcute]rmino  \
constante del polinomio lineal ajustado es el ",
  StyleBox["ln b, ",
    FontWeight->"Bold"],
  "entonces ",
  StyleBox["b es igual a la exponencial de este t\[EAcute]rmino. ",
    FontWeight->"Bold"],
  "Obtenga el valor de ",
  StyleBox["b.",
    FontWeight->"Bold"],
  " El coeficiente del t\[EAcute]rmino lineal es",
  StyleBox[" a.",
    FontWeight->"Bold"],
  "  \n(d) Defina la funci\[OAcute]n exponencial ajustada a los datos  \
originales de acuerdo a los incisos (b) y (c), graf\[IAcute]quela en el  \
intervalo en el cual se encuentran los datos y compare esta gr\[AAcute]fica  \
con la de los datos de la lista original. \n(f) Muestre las  gr\[AAcute]ficas \
de las dos funciones ajustadas y la de los datos en la lista  original.\n(h) \
Calcule el error cuadr\[AAcute]tico medio cometido con cada  ajuste.\n(g) \
Escriba sus concluciones. "
}], "Text",
  Evaluatable->False,
  TextAlignment->AlignmentMarker,
  TextJustification->1,
  FontFamily->"Times New Roman"],

Cell["Bibliograf\[IAcute]a", "Section"],

Cell["\<\
* William T. Shaw y Jason Tigg, Applied Mathematica: Getting \
started, getting it done. Addison-Wesley Publishing Co. E. U. A. 1994.
* Ira N. Levine, Fisicoqu\[IAcute]mica. Cuarta Edici\[OAcute]n. McGraw-Hill. \
Espa\[NTilde]a 1996.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{647, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 92, 3, 168, "Title"],
Cell[1812, 54, 930, 17, 207, "MathCaption"],
Cell[2745, 73, 49, 0, 106, "Section"],
Cell[2797, 75, 1088, 18, 200, "Text"],
Cell[3888, 95, 59, 0, 49, "Subsection"],
Cell[3950, 97, 4540, 179, 474, "Text"],
Cell[8493, 278, 75, 0, 49, "Subsection"],
Cell[8571, 280, 4842, 199, 710, "Text"],
Cell[13416, 481, 527, 10, 86, "Text"],
Cell[13946, 493, 248, 8, 55, "Input"],
Cell[14197, 503, 205, 6, 29, "Text"],
Cell[14405, 511, 80, 2, 35, "Input"],
Cell[14488, 515, 172, 5, 29, "Text"],
Cell[14663, 522, 81, 2, 35, "Input"],
Cell[14747, 526, 133, 3, 29, "Text"],
Cell[14883, 531, 42, 0, 106, "Section"],
Cell[14928, 533, 868, 25, 106, "Text",
  Evaluatable->False],
Cell[15799, 560, 181, 6, 58, "Input"],
Cell[15983, 568, 879, 23, 107, "Text",
  Evaluatable->False],
Cell[16865, 593, 96, 2, 38, "Input"],
Cell[16964, 597, 774, 20, 89, "Text",
  Evaluatable->False],
Cell[17741, 619, 117, 2, 38, "Input"],
Cell[17861, 623, 257, 9, 30, "Text",
  Evaluatable->False],
Cell[18121, 634, 79, 2, 38, "Input"],
Cell[18203, 638, 701, 23, 69, "Text",
  Evaluatable->False],
Cell[18907, 663, 77, 2, 35, "Input"],
Cell[18987, 667, 489, 13, 69, "Text"],
Cell[19479, 682, 529, 16, 85, "Text",
  Evaluatable->False],
Cell[20011, 700, 488, 14, 69, "Text",
  Evaluatable->False],
Cell[20502, 716, 193, 6, 58, "Input"],
Cell[20698, 724, 458, 12, 69, "Text",
  Evaluatable->False],
Cell[21159, 738, 83, 2, 38, "Input"],
Cell[21245, 742, 212, 7, 29, "Text",
  Evaluatable->False],
Cell[21460, 751, 83, 2, 38, "Input"],
Cell[21546, 755, 454, 10, 67, "Text",
  Evaluatable->False],
Cell[22003, 767, 771, 26, 68, "Text",
  Evaluatable->False],
Cell[22777, 795, 191, 5, 61, "Input"],
Cell[22971, 802, 432, 12, 69, "Text"],
Cell[23406, 816, 57, 0, 49, "Subsection"],
Cell[23466, 818, 619, 17, 96, "Text"],
Cell[24088, 837, 259, 9, 81, "Input"],
Cell[24350, 848, 613, 16, 68, "Text",
  Evaluatable->False],
Cell[24966, 866, 190, 6, 58, "Input"],
Cell[25159, 874, 1044, 28, 127, "Text",
  Evaluatable->False],
Cell[26206, 904, 180, 6, 58, "Input"],
Cell[26389, 912, 425, 17, 111, "Text"],
Cell[26817, 931, 285, 9, 30, "Text"],
Cell[27105, 942, 190, 6, 58, "Input"],
Cell[27298, 950, 190, 6, 29, "Text"],
Cell[27491, 958, 183, 6, 58, "Input"],
Cell[27677, 966, 256, 6, 48, "Text"],
Cell[27936, 974, 483, 15, 50, "Text"],
Cell[28422, 991, 182, 6, 58, "Input"],
Cell[28607, 999, 318, 9, 48, "Text"],
Cell[28928, 1010, 57, 0, 49, "Subsection"],
Cell[28988, 1012, 311, 8, 48, "Text"],
Cell[29302, 1022, 263, 8, 29, "Text"],
Cell[29568, 1032, 152, 5, 61, "Input"],
Cell[29723, 1039, 274, 8, 29, "Text"],
Cell[30000, 1049, 87, 2, 38, "Input"],
Cell[30090, 1053, 230, 8, 29, "Text"],
Cell[30323, 1063, 74, 2, 38, "Input"],
Cell[30400, 1067, 141, 3, 29, "Text"],
Cell[30544, 1072, 84, 2, 38, "Input"],
Cell[30631, 1076, 233, 6, 48, "Text"],
Cell[30867, 1084, 77, 2, 38, "Input"],
Cell[30947, 1088, 679, 22, 95, "Text"],
Cell[31629, 1112, 76, 2, 38, "Input"],
Cell[31708, 1116, 134, 3, 29, "Text"],
Cell[31845, 1121, 76, 2, 35, "Input"],
Cell[31924, 1125, 449, 13, 67, "Text"],
Cell[32376, 1140, 86, 2, 38, "Input"],
Cell[32465, 1144, 333, 12, 50, "Text"],
Cell[32801, 1158, 89, 2, 35, "Input"],
Cell[32893, 1162, 103, 2, 29, "Text"],
Cell[32999, 1166, 86, 2, 35, "Input"],
Cell[33088, 1170, 191, 6, 48, "Text"],
Cell[33282, 1178, 368, 16, 57, "Text"],
Cell[33653, 1196, 524, 20, 78, "Text"],
Cell[34180, 1218, 573, 16, 130, "Text"],
Cell[34756, 1236, 31, 0, 106, "Section"],
Cell[34790, 1238, 339, 8, 48, "Text",
  Evaluatable->False],
Cell[35132, 1248, 76, 2, 38, "Input"],
Cell[35211, 1252, 398, 9, 67, "Text",
  Evaluatable->False],
Cell[35612, 1263, 224, 7, 55, "Input"],
Cell[35839, 1272, 378, 11, 49, "Text",
  Evaluatable->False],
Cell[36220, 1285, 61, 1, 38, "Input"],
Cell[36284, 1288, 328, 10, 49, "Text",
  Evaluatable->False],
Cell[36615, 1300, 82, 1, 38, "Input"],
Cell[36700, 1303, 169, 4, 29, "Text",
  Evaluatable->False],
Cell[36872, 1309, 54, 1, 38, "Input"],
Cell[36929, 1312, 433, 14, 84, "Text",
  Evaluatable->False],
Cell[37365, 1328, 365, 12, 29, "Text",
  Evaluatable->False],
Cell[37733, 1342, 124, 4, 61, "Input"],
Cell[37860, 1348, 399, 9, 67, "Text",
  Evaluatable->False],
Cell[38262, 1359, 83, 1, 38, "Input"],
Cell[38348, 1362, 185, 4, 29, "Text",
  Evaluatable->False],
Cell[38536, 1368, 94, 1, 38, "Input"],
Cell[38633, 1371, 209, 7, 29, "Text",
  Evaluatable->False],
Cell[38845, 1380, 54, 1, 38, "Input"],
Cell[38902, 1383, 755, 15, 106, "Text",
  Evaluatable->False],
Cell[39660, 1400, 69, 1, 38, "Input"],
Cell[39732, 1403, 535, 13, 94, "Text",
  Evaluatable->False],
Cell[40270, 1418, 53, 1, 38, "Input"],
Cell[40326, 1421, 412, 10, 68, "Text",
  Evaluatable->False],
Cell[40741, 1433, 72, 1, 38, "Input"],
Cell[40816, 1436, 264, 6, 48, "Text",
  Evaluatable->False],
Cell[41083, 1444, 54, 1, 38, "Input"],
Cell[41140, 1447, 1335, 37, 189, "Text",
  Evaluatable->False],
Cell[42478, 1486, 60, 0, 106, "Section"],
Cell[42541, 1488, 1572, 41, 209, "Text",
  Evaluatable->False],
Cell[44116, 1531, 163, 5, 61, "Input"],
Cell[44282, 1538, 1265, 24, 226, "Text",
  Evaluatable->False],
Cell[45550, 1564, 92, 2, 38, "Input"],
Cell[45645, 1568, 212, 7, 29, "Text",
  Evaluatable->False],
Cell[45860, 1577, 282, 8, 48, "Text",
  Evaluatable->False],
Cell[46145, 1587, 239, 9, 153, "Input"],
Cell[46387, 1598, 288, 9, 29, "Text",
  Evaluatable->False],
Cell[46678, 1609, 345, 13, 173, "Input"],
Cell[47026, 1624, 440, 12, 49, "Text",
  Evaluatable->False],
Cell[47469, 1638, 121, 2, 38, "Input"],
Cell[47593, 1642, 634, 17, 88, "Text",
  Evaluatable->False],
Cell[48230, 1661, 107, 2, 38, "Input"],
Cell[48340, 1665, 422, 11, 49, "Text",
  Evaluatable->False],
Cell[48765, 1678, 253, 10, 176, "Input"],
Cell[49021, 1690, 608, 16, 68, "Text",
  Evaluatable->False],
Cell[49632, 1708, 80, 2, 38, "Input"],
Cell[49715, 1712, 891, 19, 105, "Text"],
Cell[50609, 1733, 4321, 121, 519, "Text",
  Evaluatable->False],
Cell[54933, 1856, 39, 0, 106, "Section"],
Cell[54975, 1858, 304, 7, 75, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

